// Copyright 2015, VIXL authors
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//
//   * Redistributions of source code must retain the above copyright notice,
//     this list of conditions and the following disclaimer.
//   * Redistributions in binary form must reproduce the above copyright notice,
//     this list of conditions and the following disclaimer in the documentation
//     and/or other materials provided with the distribution.
//   * Neither the name of ARM Limited nor the names of its contributors may be
//     used to endorse or promote products derived from this software without
//     specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


// ---------------------------------------------------------------------
// This file is auto generated using tools/generate_simulator_traces.py.
//
// PLEASE DO NOT EDIT.
// ---------------------------------------------------------------------

#ifndef VIXL_ASSEMBLER_COND_RD_OPERAND_RN_TEQ_T32_H_
#define VIXL_ASSEMBLER_COND_RD_OPERAND_RN_TEQ_T32_H_

const byte kInstruction_teq_al_r0_r0[] = {
  0x90, 0xea, 0x00, 0x0f // teq al r0 r0
};
const byte kInstruction_teq_al_r0_r1[] = {
  0x90, 0xea, 0x01, 0x0f // teq al r0 r1
};
const byte kInstruction_teq_al_r0_r2[] = {
  0x90, 0xea, 0x02, 0x0f // teq al r0 r2
};
const byte kInstruction_teq_al_r0_r3[] = {
  0x90, 0xea, 0x03, 0x0f // teq al r0 r3
};
const byte kInstruction_teq_al_r0_r4[] = {
  0x90, 0xea, 0x04, 0x0f // teq al r0 r4
};
const byte kInstruction_teq_al_r0_r5[] = {
  0x90, 0xea, 0x05, 0x0f // teq al r0 r5
};
const byte kInstruction_teq_al_r0_r6[] = {
  0x90, 0xea, 0x06, 0x0f // teq al r0 r6
};
const byte kInstruction_teq_al_r0_r7[] = {
  0x90, 0xea, 0x07, 0x0f // teq al r0 r7
};
const byte kInstruction_teq_al_r0_r8[] = {
  0x90, 0xea, 0x08, 0x0f // teq al r0 r8
};
const byte kInstruction_teq_al_r0_r9[] = {
  0x90, 0xea, 0x09, 0x0f // teq al r0 r9
};
const byte kInstruction_teq_al_r0_r10[] = {
  0x90, 0xea, 0x0a, 0x0f // teq al r0 r10
};
const byte kInstruction_teq_al_r0_r11[] = {
  0x90, 0xea, 0x0b, 0x0f // teq al r0 r11
};
const byte kInstruction_teq_al_r0_r12[] = {
  0x90, 0xea, 0x0c, 0x0f // teq al r0 r12
};
const byte kInstruction_teq_al_r0_r13[] = {
  0x90, 0xea, 0x0d, 0x0f // teq al r0 r13
};
const byte kInstruction_teq_al_r0_r14[] = {
  0x90, 0xea, 0x0e, 0x0f // teq al r0 r14
};
const byte kInstruction_teq_al_r1_r0[] = {
  0x91, 0xea, 0x00, 0x0f // teq al r1 r0
};
const byte kInstruction_teq_al_r1_r1[] = {
  0x91, 0xea, 0x01, 0x0f // teq al r1 r1
};
const byte kInstruction_teq_al_r1_r2[] = {
  0x91, 0xea, 0x02, 0x0f // teq al r1 r2
};
const byte kInstruction_teq_al_r1_r3[] = {
  0x91, 0xea, 0x03, 0x0f // teq al r1 r3
};
const byte kInstruction_teq_al_r1_r4[] = {
  0x91, 0xea, 0x04, 0x0f // teq al r1 r4
};
const byte kInstruction_teq_al_r1_r5[] = {
  0x91, 0xea, 0x05, 0x0f // teq al r1 r5
};
const byte kInstruction_teq_al_r1_r6[] = {
  0x91, 0xea, 0x06, 0x0f // teq al r1 r6
};
const byte kInstruction_teq_al_r1_r7[] = {
  0x91, 0xea, 0x07, 0x0f // teq al r1 r7
};
const byte kInstruction_teq_al_r1_r8[] = {
  0x91, 0xea, 0x08, 0x0f // teq al r1 r8
};
const byte kInstruction_teq_al_r1_r9[] = {
  0x91, 0xea, 0x09, 0x0f // teq al r1 r9
};
const byte kInstruction_teq_al_r1_r10[] = {
  0x91, 0xea, 0x0a, 0x0f // teq al r1 r10
};
const byte kInstruction_teq_al_r1_r11[] = {
  0x91, 0xea, 0x0b, 0x0f // teq al r1 r11
};
const byte kInstruction_teq_al_r1_r12[] = {
  0x91, 0xea, 0x0c, 0x0f // teq al r1 r12
};
const byte kInstruction_teq_al_r1_r13[] = {
  0x91, 0xea, 0x0d, 0x0f // teq al r1 r13
};
const byte kInstruction_teq_al_r1_r14[] = {
  0x91, 0xea, 0x0e, 0x0f // teq al r1 r14
};
const byte kInstruction_teq_al_r2_r0[] = {
  0x92, 0xea, 0x00, 0x0f // teq al r2 r0
};
const byte kInstruction_teq_al_r2_r1[] = {
  0x92, 0xea, 0x01, 0x0f // teq al r2 r1
};
const byte kInstruction_teq_al_r2_r2[] = {
  0x92, 0xea, 0x02, 0x0f // teq al r2 r2
};
const byte kInstruction_teq_al_r2_r3[] = {
  0x92, 0xea, 0x03, 0x0f // teq al r2 r3
};
const byte kInstruction_teq_al_r2_r4[] = {
  0x92, 0xea, 0x04, 0x0f // teq al r2 r4
};
const byte kInstruction_teq_al_r2_r5[] = {
  0x92, 0xea, 0x05, 0x0f // teq al r2 r5
};
const byte kInstruction_teq_al_r2_r6[] = {
  0x92, 0xea, 0x06, 0x0f // teq al r2 r6
};
const byte kInstruction_teq_al_r2_r7[] = {
  0x92, 0xea, 0x07, 0x0f // teq al r2 r7
};
const byte kInstruction_teq_al_r2_r8[] = {
  0x92, 0xea, 0x08, 0x0f // teq al r2 r8
};
const byte kInstruction_teq_al_r2_r9[] = {
  0x92, 0xea, 0x09, 0x0f // teq al r2 r9
};
const byte kInstruction_teq_al_r2_r10[] = {
  0x92, 0xea, 0x0a, 0x0f // teq al r2 r10
};
const byte kInstruction_teq_al_r2_r11[] = {
  0x92, 0xea, 0x0b, 0x0f // teq al r2 r11
};
const byte kInstruction_teq_al_r2_r12[] = {
  0x92, 0xea, 0x0c, 0x0f // teq al r2 r12
};
const byte kInstruction_teq_al_r2_r13[] = {
  0x92, 0xea, 0x0d, 0x0f // teq al r2 r13
};
const byte kInstruction_teq_al_r2_r14[] = {
  0x92, 0xea, 0x0e, 0x0f // teq al r2 r14
};
const byte kInstruction_teq_al_r3_r0[] = {
  0x93, 0xea, 0x00, 0x0f // teq al r3 r0
};
const byte kInstruction_teq_al_r3_r1[] = {
  0x93, 0xea, 0x01, 0x0f // teq al r3 r1
};
const byte kInstruction_teq_al_r3_r2[] = {
  0x93, 0xea, 0x02, 0x0f // teq al r3 r2
};
const byte kInstruction_teq_al_r3_r3[] = {
  0x93, 0xea, 0x03, 0x0f // teq al r3 r3
};
const byte kInstruction_teq_al_r3_r4[] = {
  0x93, 0xea, 0x04, 0x0f // teq al r3 r4
};
const byte kInstruction_teq_al_r3_r5[] = {
  0x93, 0xea, 0x05, 0x0f // teq al r3 r5
};
const byte kInstruction_teq_al_r3_r6[] = {
  0x93, 0xea, 0x06, 0x0f // teq al r3 r6
};
const byte kInstruction_teq_al_r3_r7[] = {
  0x93, 0xea, 0x07, 0x0f // teq al r3 r7
};
const byte kInstruction_teq_al_r3_r8[] = {
  0x93, 0xea, 0x08, 0x0f // teq al r3 r8
};
const byte kInstruction_teq_al_r3_r9[] = {
  0x93, 0xea, 0x09, 0x0f // teq al r3 r9
};
const byte kInstruction_teq_al_r3_r10[] = {
  0x93, 0xea, 0x0a, 0x0f // teq al r3 r10
};
const byte kInstruction_teq_al_r3_r11[] = {
  0x93, 0xea, 0x0b, 0x0f // teq al r3 r11
};
const byte kInstruction_teq_al_r3_r12[] = {
  0x93, 0xea, 0x0c, 0x0f // teq al r3 r12
};
const byte kInstruction_teq_al_r3_r13[] = {
  0x93, 0xea, 0x0d, 0x0f // teq al r3 r13
};
const byte kInstruction_teq_al_r3_r14[] = {
  0x93, 0xea, 0x0e, 0x0f // teq al r3 r14
};
const byte kInstruction_teq_al_r4_r0[] = {
  0x94, 0xea, 0x00, 0x0f // teq al r4 r0
};
const byte kInstruction_teq_al_r4_r1[] = {
  0x94, 0xea, 0x01, 0x0f // teq al r4 r1
};
const byte kInstruction_teq_al_r4_r2[] = {
  0x94, 0xea, 0x02, 0x0f // teq al r4 r2
};
const byte kInstruction_teq_al_r4_r3[] = {
  0x94, 0xea, 0x03, 0x0f // teq al r4 r3
};
const byte kInstruction_teq_al_r4_r4[] = {
  0x94, 0xea, 0x04, 0x0f // teq al r4 r4
};
const byte kInstruction_teq_al_r4_r5[] = {
  0x94, 0xea, 0x05, 0x0f // teq al r4 r5
};
const byte kInstruction_teq_al_r4_r6[] = {
  0x94, 0xea, 0x06, 0x0f // teq al r4 r6
};
const byte kInstruction_teq_al_r4_r7[] = {
  0x94, 0xea, 0x07, 0x0f // teq al r4 r7
};
const byte kInstruction_teq_al_r4_r8[] = {
  0x94, 0xea, 0x08, 0x0f // teq al r4 r8
};
const byte kInstruction_teq_al_r4_r9[] = {
  0x94, 0xea, 0x09, 0x0f // teq al r4 r9
};
const byte kInstruction_teq_al_r4_r10[] = {
  0x94, 0xea, 0x0a, 0x0f // teq al r4 r10
};
const byte kInstruction_teq_al_r4_r11[] = {
  0x94, 0xea, 0x0b, 0x0f // teq al r4 r11
};
const byte kInstruction_teq_al_r4_r12[] = {
  0x94, 0xea, 0x0c, 0x0f // teq al r4 r12
};
const byte kInstruction_teq_al_r4_r13[] = {
  0x94, 0xea, 0x0d, 0x0f // teq al r4 r13
};
const byte kInstruction_teq_al_r4_r14[] = {
  0x94, 0xea, 0x0e, 0x0f // teq al r4 r14
};
const byte kInstruction_teq_al_r5_r0[] = {
  0x95, 0xea, 0x00, 0x0f // teq al r5 r0
};
const byte kInstruction_teq_al_r5_r1[] = {
  0x95, 0xea, 0x01, 0x0f // teq al r5 r1
};
const byte kInstruction_teq_al_r5_r2[] = {
  0x95, 0xea, 0x02, 0x0f // teq al r5 r2
};
const byte kInstruction_teq_al_r5_r3[] = {
  0x95, 0xea, 0x03, 0x0f // teq al r5 r3
};
const byte kInstruction_teq_al_r5_r4[] = {
  0x95, 0xea, 0x04, 0x0f // teq al r5 r4
};
const byte kInstruction_teq_al_r5_r5[] = {
  0x95, 0xea, 0x05, 0x0f // teq al r5 r5
};
const byte kInstruction_teq_al_r5_r6[] = {
  0x95, 0xea, 0x06, 0x0f // teq al r5 r6
};
const byte kInstruction_teq_al_r5_r7[] = {
  0x95, 0xea, 0x07, 0x0f // teq al r5 r7
};
const byte kInstruction_teq_al_r5_r8[] = {
  0x95, 0xea, 0x08, 0x0f // teq al r5 r8
};
const byte kInstruction_teq_al_r5_r9[] = {
  0x95, 0xea, 0x09, 0x0f // teq al r5 r9
};
const byte kInstruction_teq_al_r5_r10[] = {
  0x95, 0xea, 0x0a, 0x0f // teq al r5 r10
};
const byte kInstruction_teq_al_r5_r11[] = {
  0x95, 0xea, 0x0b, 0x0f // teq al r5 r11
};
const byte kInstruction_teq_al_r5_r12[] = {
  0x95, 0xea, 0x0c, 0x0f // teq al r5 r12
};
const byte kInstruction_teq_al_r5_r13[] = {
  0x95, 0xea, 0x0d, 0x0f // teq al r5 r13
};
const byte kInstruction_teq_al_r5_r14[] = {
  0x95, 0xea, 0x0e, 0x0f // teq al r5 r14
};
const byte kInstruction_teq_al_r6_r0[] = {
  0x96, 0xea, 0x00, 0x0f // teq al r6 r0
};
const byte kInstruction_teq_al_r6_r1[] = {
  0x96, 0xea, 0x01, 0x0f // teq al r6 r1
};
const byte kInstruction_teq_al_r6_r2[] = {
  0x96, 0xea, 0x02, 0x0f // teq al r6 r2
};
const byte kInstruction_teq_al_r6_r3[] = {
  0x96, 0xea, 0x03, 0x0f // teq al r6 r3
};
const byte kInstruction_teq_al_r6_r4[] = {
  0x96, 0xea, 0x04, 0x0f // teq al r6 r4
};
const byte kInstruction_teq_al_r6_r5[] = {
  0x96, 0xea, 0x05, 0x0f // teq al r6 r5
};
const byte kInstruction_teq_al_r6_r6[] = {
  0x96, 0xea, 0x06, 0x0f // teq al r6 r6
};
const byte kInstruction_teq_al_r6_r7[] = {
  0x96, 0xea, 0x07, 0x0f // teq al r6 r7
};
const byte kInstruction_teq_al_r6_r8[] = {
  0x96, 0xea, 0x08, 0x0f // teq al r6 r8
};
const byte kInstruction_teq_al_r6_r9[] = {
  0x96, 0xea, 0x09, 0x0f // teq al r6 r9
};
const byte kInstruction_teq_al_r6_r10[] = {
  0x96, 0xea, 0x0a, 0x0f // teq al r6 r10
};
const byte kInstruction_teq_al_r6_r11[] = {
  0x96, 0xea, 0x0b, 0x0f // teq al r6 r11
};
const byte kInstruction_teq_al_r6_r12[] = {
  0x96, 0xea, 0x0c, 0x0f // teq al r6 r12
};
const byte kInstruction_teq_al_r6_r13[] = {
  0x96, 0xea, 0x0d, 0x0f // teq al r6 r13
};
const byte kInstruction_teq_al_r6_r14[] = {
  0x96, 0xea, 0x0e, 0x0f // teq al r6 r14
};
const byte kInstruction_teq_al_r7_r0[] = {
  0x97, 0xea, 0x00, 0x0f // teq al r7 r0
};
const byte kInstruction_teq_al_r7_r1[] = {
  0x97, 0xea, 0x01, 0x0f // teq al r7 r1
};
const byte kInstruction_teq_al_r7_r2[] = {
  0x97, 0xea, 0x02, 0x0f // teq al r7 r2
};
const byte kInstruction_teq_al_r7_r3[] = {
  0x97, 0xea, 0x03, 0x0f // teq al r7 r3
};
const byte kInstruction_teq_al_r7_r4[] = {
  0x97, 0xea, 0x04, 0x0f // teq al r7 r4
};
const byte kInstruction_teq_al_r7_r5[] = {
  0x97, 0xea, 0x05, 0x0f // teq al r7 r5
};
const byte kInstruction_teq_al_r7_r6[] = {
  0x97, 0xea, 0x06, 0x0f // teq al r7 r6
};
const byte kInstruction_teq_al_r7_r7[] = {
  0x97, 0xea, 0x07, 0x0f // teq al r7 r7
};
const byte kInstruction_teq_al_r7_r8[] = {
  0x97, 0xea, 0x08, 0x0f // teq al r7 r8
};
const byte kInstruction_teq_al_r7_r9[] = {
  0x97, 0xea, 0x09, 0x0f // teq al r7 r9
};
const byte kInstruction_teq_al_r7_r10[] = {
  0x97, 0xea, 0x0a, 0x0f // teq al r7 r10
};
const byte kInstruction_teq_al_r7_r11[] = {
  0x97, 0xea, 0x0b, 0x0f // teq al r7 r11
};
const byte kInstruction_teq_al_r7_r12[] = {
  0x97, 0xea, 0x0c, 0x0f // teq al r7 r12
};
const byte kInstruction_teq_al_r7_r13[] = {
  0x97, 0xea, 0x0d, 0x0f // teq al r7 r13
};
const byte kInstruction_teq_al_r7_r14[] = {
  0x97, 0xea, 0x0e, 0x0f // teq al r7 r14
};
const byte kInstruction_teq_al_r8_r0[] = {
  0x98, 0xea, 0x00, 0x0f // teq al r8 r0
};
const byte kInstruction_teq_al_r8_r1[] = {
  0x98, 0xea, 0x01, 0x0f // teq al r8 r1
};
const byte kInstruction_teq_al_r8_r2[] = {
  0x98, 0xea, 0x02, 0x0f // teq al r8 r2
};
const byte kInstruction_teq_al_r8_r3[] = {
  0x98, 0xea, 0x03, 0x0f // teq al r8 r3
};
const byte kInstruction_teq_al_r8_r4[] = {
  0x98, 0xea, 0x04, 0x0f // teq al r8 r4
};
const byte kInstruction_teq_al_r8_r5[] = {
  0x98, 0xea, 0x05, 0x0f // teq al r8 r5
};
const byte kInstruction_teq_al_r8_r6[] = {
  0x98, 0xea, 0x06, 0x0f // teq al r8 r6
};
const byte kInstruction_teq_al_r8_r7[] = {
  0x98, 0xea, 0x07, 0x0f // teq al r8 r7
};
const byte kInstruction_teq_al_r8_r8[] = {
  0x98, 0xea, 0x08, 0x0f // teq al r8 r8
};
const byte kInstruction_teq_al_r8_r9[] = {
  0x98, 0xea, 0x09, 0x0f // teq al r8 r9
};
const byte kInstruction_teq_al_r8_r10[] = {
  0x98, 0xea, 0x0a, 0x0f // teq al r8 r10
};
const byte kInstruction_teq_al_r8_r11[] = {
  0x98, 0xea, 0x0b, 0x0f // teq al r8 r11
};
const byte kInstruction_teq_al_r8_r12[] = {
  0x98, 0xea, 0x0c, 0x0f // teq al r8 r12
};
const byte kInstruction_teq_al_r8_r13[] = {
  0x98, 0xea, 0x0d, 0x0f // teq al r8 r13
};
const byte kInstruction_teq_al_r8_r14[] = {
  0x98, 0xea, 0x0e, 0x0f // teq al r8 r14
};
const byte kInstruction_teq_al_r9_r0[] = {
  0x99, 0xea, 0x00, 0x0f // teq al r9 r0
};
const byte kInstruction_teq_al_r9_r1[] = {
  0x99, 0xea, 0x01, 0x0f // teq al r9 r1
};
const byte kInstruction_teq_al_r9_r2[] = {
  0x99, 0xea, 0x02, 0x0f // teq al r9 r2
};
const byte kInstruction_teq_al_r9_r3[] = {
  0x99, 0xea, 0x03, 0x0f // teq al r9 r3
};
const byte kInstruction_teq_al_r9_r4[] = {
  0x99, 0xea, 0x04, 0x0f // teq al r9 r4
};
const byte kInstruction_teq_al_r9_r5[] = {
  0x99, 0xea, 0x05, 0x0f // teq al r9 r5
};
const byte kInstruction_teq_al_r9_r6[] = {
  0x99, 0xea, 0x06, 0x0f // teq al r9 r6
};
const byte kInstruction_teq_al_r9_r7[] = {
  0x99, 0xea, 0x07, 0x0f // teq al r9 r7
};
const byte kInstruction_teq_al_r9_r8[] = {
  0x99, 0xea, 0x08, 0x0f // teq al r9 r8
};
const byte kInstruction_teq_al_r9_r9[] = {
  0x99, 0xea, 0x09, 0x0f // teq al r9 r9
};
const byte kInstruction_teq_al_r9_r10[] = {
  0x99, 0xea, 0x0a, 0x0f // teq al r9 r10
};
const byte kInstruction_teq_al_r9_r11[] = {
  0x99, 0xea, 0x0b, 0x0f // teq al r9 r11
};
const byte kInstruction_teq_al_r9_r12[] = {
  0x99, 0xea, 0x0c, 0x0f // teq al r9 r12
};
const byte kInstruction_teq_al_r9_r13[] = {
  0x99, 0xea, 0x0d, 0x0f // teq al r9 r13
};
const byte kInstruction_teq_al_r9_r14[] = {
  0x99, 0xea, 0x0e, 0x0f // teq al r9 r14
};
const byte kInstruction_teq_al_r10_r0[] = {
  0x9a, 0xea, 0x00, 0x0f // teq al r10 r0
};
const byte kInstruction_teq_al_r10_r1[] = {
  0x9a, 0xea, 0x01, 0x0f // teq al r10 r1
};
const byte kInstruction_teq_al_r10_r2[] = {
  0x9a, 0xea, 0x02, 0x0f // teq al r10 r2
};
const byte kInstruction_teq_al_r10_r3[] = {
  0x9a, 0xea, 0x03, 0x0f // teq al r10 r3
};
const byte kInstruction_teq_al_r10_r4[] = {
  0x9a, 0xea, 0x04, 0x0f // teq al r10 r4
};
const byte kInstruction_teq_al_r10_r5[] = {
  0x9a, 0xea, 0x05, 0x0f // teq al r10 r5
};
const byte kInstruction_teq_al_r10_r6[] = {
  0x9a, 0xea, 0x06, 0x0f // teq al r10 r6
};
const byte kInstruction_teq_al_r10_r7[] = {
  0x9a, 0xea, 0x07, 0x0f // teq al r10 r7
};
const byte kInstruction_teq_al_r10_r8[] = {
  0x9a, 0xea, 0x08, 0x0f // teq al r10 r8
};
const byte kInstruction_teq_al_r10_r9[] = {
  0x9a, 0xea, 0x09, 0x0f // teq al r10 r9
};
const byte kInstruction_teq_al_r10_r10[] = {
  0x9a, 0xea, 0x0a, 0x0f // teq al r10 r10
};
const byte kInstruction_teq_al_r10_r11[] = {
  0x9a, 0xea, 0x0b, 0x0f // teq al r10 r11
};
const byte kInstruction_teq_al_r10_r12[] = {
  0x9a, 0xea, 0x0c, 0x0f // teq al r10 r12
};
const byte kInstruction_teq_al_r10_r13[] = {
  0x9a, 0xea, 0x0d, 0x0f // teq al r10 r13
};
const byte kInstruction_teq_al_r10_r14[] = {
  0x9a, 0xea, 0x0e, 0x0f // teq al r10 r14
};
const byte kInstruction_teq_al_r11_r0[] = {
  0x9b, 0xea, 0x00, 0x0f // teq al r11 r0
};
const byte kInstruction_teq_al_r11_r1[] = {
  0x9b, 0xea, 0x01, 0x0f // teq al r11 r1
};
const byte kInstruction_teq_al_r11_r2[] = {
  0x9b, 0xea, 0x02, 0x0f // teq al r11 r2
};
const byte kInstruction_teq_al_r11_r3[] = {
  0x9b, 0xea, 0x03, 0x0f // teq al r11 r3
};
const byte kInstruction_teq_al_r11_r4[] = {
  0x9b, 0xea, 0x04, 0x0f // teq al r11 r4
};
const byte kInstruction_teq_al_r11_r5[] = {
  0x9b, 0xea, 0x05, 0x0f // teq al r11 r5
};
const byte kInstruction_teq_al_r11_r6[] = {
  0x9b, 0xea, 0x06, 0x0f // teq al r11 r6
};
const byte kInstruction_teq_al_r11_r7[] = {
  0x9b, 0xea, 0x07, 0x0f // teq al r11 r7
};
const byte kInstruction_teq_al_r11_r8[] = {
  0x9b, 0xea, 0x08, 0x0f // teq al r11 r8
};
const byte kInstruction_teq_al_r11_r9[] = {
  0x9b, 0xea, 0x09, 0x0f // teq al r11 r9
};
const byte kInstruction_teq_al_r11_r10[] = {
  0x9b, 0xea, 0x0a, 0x0f // teq al r11 r10
};
const byte kInstruction_teq_al_r11_r11[] = {
  0x9b, 0xea, 0x0b, 0x0f // teq al r11 r11
};
const byte kInstruction_teq_al_r11_r12[] = {
  0x9b, 0xea, 0x0c, 0x0f // teq al r11 r12
};
const byte kInstruction_teq_al_r11_r13[] = {
  0x9b, 0xea, 0x0d, 0x0f // teq al r11 r13
};
const byte kInstruction_teq_al_r11_r14[] = {
  0x9b, 0xea, 0x0e, 0x0f // teq al r11 r14
};
const byte kInstruction_teq_al_r12_r0[] = {
  0x9c, 0xea, 0x00, 0x0f // teq al r12 r0
};
const byte kInstruction_teq_al_r12_r1[] = {
  0x9c, 0xea, 0x01, 0x0f // teq al r12 r1
};
const byte kInstruction_teq_al_r12_r2[] = {
  0x9c, 0xea, 0x02, 0x0f // teq al r12 r2
};
const byte kInstruction_teq_al_r12_r3[] = {
  0x9c, 0xea, 0x03, 0x0f // teq al r12 r3
};
const byte kInstruction_teq_al_r12_r4[] = {
  0x9c, 0xea, 0x04, 0x0f // teq al r12 r4
};
const byte kInstruction_teq_al_r12_r5[] = {
  0x9c, 0xea, 0x05, 0x0f // teq al r12 r5
};
const byte kInstruction_teq_al_r12_r6[] = {
  0x9c, 0xea, 0x06, 0x0f // teq al r12 r6
};
const byte kInstruction_teq_al_r12_r7[] = {
  0x9c, 0xea, 0x07, 0x0f // teq al r12 r7
};
const byte kInstruction_teq_al_r12_r8[] = {
  0x9c, 0xea, 0x08, 0x0f // teq al r12 r8
};
const byte kInstruction_teq_al_r12_r9[] = {
  0x9c, 0xea, 0x09, 0x0f // teq al r12 r9
};
const byte kInstruction_teq_al_r12_r10[] = {
  0x9c, 0xea, 0x0a, 0x0f // teq al r12 r10
};
const byte kInstruction_teq_al_r12_r11[] = {
  0x9c, 0xea, 0x0b, 0x0f // teq al r12 r11
};
const byte kInstruction_teq_al_r12_r12[] = {
  0x9c, 0xea, 0x0c, 0x0f // teq al r12 r12
};
const byte kInstruction_teq_al_r12_r13[] = {
  0x9c, 0xea, 0x0d, 0x0f // teq al r12 r13
};
const byte kInstruction_teq_al_r12_r14[] = {
  0x9c, 0xea, 0x0e, 0x0f // teq al r12 r14
};
const byte kInstruction_teq_al_r13_r0[] = {
  0x9d, 0xea, 0x00, 0x0f // teq al r13 r0
};
const byte kInstruction_teq_al_r13_r1[] = {
  0x9d, 0xea, 0x01, 0x0f // teq al r13 r1
};
const byte kInstruction_teq_al_r13_r2[] = {
  0x9d, 0xea, 0x02, 0x0f // teq al r13 r2
};
const byte kInstruction_teq_al_r13_r3[] = {
  0x9d, 0xea, 0x03, 0x0f // teq al r13 r3
};
const byte kInstruction_teq_al_r13_r4[] = {
  0x9d, 0xea, 0x04, 0x0f // teq al r13 r4
};
const byte kInstruction_teq_al_r13_r5[] = {
  0x9d, 0xea, 0x05, 0x0f // teq al r13 r5
};
const byte kInstruction_teq_al_r13_r6[] = {
  0x9d, 0xea, 0x06, 0x0f // teq al r13 r6
};
const byte kInstruction_teq_al_r13_r7[] = {
  0x9d, 0xea, 0x07, 0x0f // teq al r13 r7
};
const byte kInstruction_teq_al_r13_r8[] = {
  0x9d, 0xea, 0x08, 0x0f // teq al r13 r8
};
const byte kInstruction_teq_al_r13_r9[] = {
  0x9d, 0xea, 0x09, 0x0f // teq al r13 r9
};
const byte kInstruction_teq_al_r13_r10[] = {
  0x9d, 0xea, 0x0a, 0x0f // teq al r13 r10
};
const byte kInstruction_teq_al_r13_r11[] = {
  0x9d, 0xea, 0x0b, 0x0f // teq al r13 r11
};
const byte kInstruction_teq_al_r13_r12[] = {
  0x9d, 0xea, 0x0c, 0x0f // teq al r13 r12
};
const byte kInstruction_teq_al_r13_r13[] = {
  0x9d, 0xea, 0x0d, 0x0f // teq al r13 r13
};
const byte kInstruction_teq_al_r13_r14[] = {
  0x9d, 0xea, 0x0e, 0x0f // teq al r13 r14
};
const byte kInstruction_teq_al_r14_r0[] = {
  0x9e, 0xea, 0x00, 0x0f // teq al r14 r0
};
const byte kInstruction_teq_al_r14_r1[] = {
  0x9e, 0xea, 0x01, 0x0f // teq al r14 r1
};
const byte kInstruction_teq_al_r14_r2[] = {
  0x9e, 0xea, 0x02, 0x0f // teq al r14 r2
};
const byte kInstruction_teq_al_r14_r3[] = {
  0x9e, 0xea, 0x03, 0x0f // teq al r14 r3
};
const byte kInstruction_teq_al_r14_r4[] = {
  0x9e, 0xea, 0x04, 0x0f // teq al r14 r4
};
const byte kInstruction_teq_al_r14_r5[] = {
  0x9e, 0xea, 0x05, 0x0f // teq al r14 r5
};
const byte kInstruction_teq_al_r14_r6[] = {
  0x9e, 0xea, 0x06, 0x0f // teq al r14 r6
};
const byte kInstruction_teq_al_r14_r7[] = {
  0x9e, 0xea, 0x07, 0x0f // teq al r14 r7
};
const byte kInstruction_teq_al_r14_r8[] = {
  0x9e, 0xea, 0x08, 0x0f // teq al r14 r8
};
const byte kInstruction_teq_al_r14_r9[] = {
  0x9e, 0xea, 0x09, 0x0f // teq al r14 r9
};
const byte kInstruction_teq_al_r14_r10[] = {
  0x9e, 0xea, 0x0a, 0x0f // teq al r14 r10
};
const byte kInstruction_teq_al_r14_r11[] = {
  0x9e, 0xea, 0x0b, 0x0f // teq al r14 r11
};
const byte kInstruction_teq_al_r14_r12[] = {
  0x9e, 0xea, 0x0c, 0x0f // teq al r14 r12
};
const byte kInstruction_teq_al_r14_r13[] = {
  0x9e, 0xea, 0x0d, 0x0f // teq al r14 r13
};
const byte kInstruction_teq_al_r14_r14[] = {
  0x9e, 0xea, 0x0e, 0x0f // teq al r14 r14
};
const TestResult kReferenceteq[] = {
  {
    ARRAY_SIZE(kInstruction_teq_al_r0_r0),
    kInstruction_teq_al_r0_r0,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r0_r1),
    kInstruction_teq_al_r0_r1,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r0_r2),
    kInstruction_teq_al_r0_r2,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r0_r3),
    kInstruction_teq_al_r0_r3,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r0_r4),
    kInstruction_teq_al_r0_r4,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r0_r5),
    kInstruction_teq_al_r0_r5,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r0_r6),
    kInstruction_teq_al_r0_r6,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r0_r7),
    kInstruction_teq_al_r0_r7,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r0_r8),
    kInstruction_teq_al_r0_r8,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r0_r9),
    kInstruction_teq_al_r0_r9,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r0_r10),
    kInstruction_teq_al_r0_r10,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r0_r11),
    kInstruction_teq_al_r0_r11,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r0_r12),
    kInstruction_teq_al_r0_r12,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r0_r13),
    kInstruction_teq_al_r0_r13,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r0_r14),
    kInstruction_teq_al_r0_r14,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r1_r0),
    kInstruction_teq_al_r1_r0,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r1_r1),
    kInstruction_teq_al_r1_r1,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r1_r2),
    kInstruction_teq_al_r1_r2,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r1_r3),
    kInstruction_teq_al_r1_r3,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r1_r4),
    kInstruction_teq_al_r1_r4,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r1_r5),
    kInstruction_teq_al_r1_r5,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r1_r6),
    kInstruction_teq_al_r1_r6,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r1_r7),
    kInstruction_teq_al_r1_r7,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r1_r8),
    kInstruction_teq_al_r1_r8,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r1_r9),
    kInstruction_teq_al_r1_r9,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r1_r10),
    kInstruction_teq_al_r1_r10,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r1_r11),
    kInstruction_teq_al_r1_r11,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r1_r12),
    kInstruction_teq_al_r1_r12,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r1_r13),
    kInstruction_teq_al_r1_r13,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r1_r14),
    kInstruction_teq_al_r1_r14,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r2_r0),
    kInstruction_teq_al_r2_r0,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r2_r1),
    kInstruction_teq_al_r2_r1,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r2_r2),
    kInstruction_teq_al_r2_r2,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r2_r3),
    kInstruction_teq_al_r2_r3,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r2_r4),
    kInstruction_teq_al_r2_r4,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r2_r5),
    kInstruction_teq_al_r2_r5,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r2_r6),
    kInstruction_teq_al_r2_r6,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r2_r7),
    kInstruction_teq_al_r2_r7,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r2_r8),
    kInstruction_teq_al_r2_r8,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r2_r9),
    kInstruction_teq_al_r2_r9,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r2_r10),
    kInstruction_teq_al_r2_r10,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r2_r11),
    kInstruction_teq_al_r2_r11,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r2_r12),
    kInstruction_teq_al_r2_r12,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r2_r13),
    kInstruction_teq_al_r2_r13,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r2_r14),
    kInstruction_teq_al_r2_r14,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r3_r0),
    kInstruction_teq_al_r3_r0,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r3_r1),
    kInstruction_teq_al_r3_r1,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r3_r2),
    kInstruction_teq_al_r3_r2,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r3_r3),
    kInstruction_teq_al_r3_r3,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r3_r4),
    kInstruction_teq_al_r3_r4,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r3_r5),
    kInstruction_teq_al_r3_r5,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r3_r6),
    kInstruction_teq_al_r3_r6,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r3_r7),
    kInstruction_teq_al_r3_r7,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r3_r8),
    kInstruction_teq_al_r3_r8,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r3_r9),
    kInstruction_teq_al_r3_r9,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r3_r10),
    kInstruction_teq_al_r3_r10,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r3_r11),
    kInstruction_teq_al_r3_r11,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r3_r12),
    kInstruction_teq_al_r3_r12,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r3_r13),
    kInstruction_teq_al_r3_r13,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r3_r14),
    kInstruction_teq_al_r3_r14,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r4_r0),
    kInstruction_teq_al_r4_r0,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r4_r1),
    kInstruction_teq_al_r4_r1,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r4_r2),
    kInstruction_teq_al_r4_r2,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r4_r3),
    kInstruction_teq_al_r4_r3,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r4_r4),
    kInstruction_teq_al_r4_r4,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r4_r5),
    kInstruction_teq_al_r4_r5,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r4_r6),
    kInstruction_teq_al_r4_r6,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r4_r7),
    kInstruction_teq_al_r4_r7,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r4_r8),
    kInstruction_teq_al_r4_r8,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r4_r9),
    kInstruction_teq_al_r4_r9,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r4_r10),
    kInstruction_teq_al_r4_r10,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r4_r11),
    kInstruction_teq_al_r4_r11,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r4_r12),
    kInstruction_teq_al_r4_r12,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r4_r13),
    kInstruction_teq_al_r4_r13,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r4_r14),
    kInstruction_teq_al_r4_r14,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r5_r0),
    kInstruction_teq_al_r5_r0,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r5_r1),
    kInstruction_teq_al_r5_r1,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r5_r2),
    kInstruction_teq_al_r5_r2,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r5_r3),
    kInstruction_teq_al_r5_r3,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r5_r4),
    kInstruction_teq_al_r5_r4,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r5_r5),
    kInstruction_teq_al_r5_r5,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r5_r6),
    kInstruction_teq_al_r5_r6,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r5_r7),
    kInstruction_teq_al_r5_r7,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r5_r8),
    kInstruction_teq_al_r5_r8,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r5_r9),
    kInstruction_teq_al_r5_r9,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r5_r10),
    kInstruction_teq_al_r5_r10,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r5_r11),
    kInstruction_teq_al_r5_r11,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r5_r12),
    kInstruction_teq_al_r5_r12,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r5_r13),
    kInstruction_teq_al_r5_r13,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r5_r14),
    kInstruction_teq_al_r5_r14,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r6_r0),
    kInstruction_teq_al_r6_r0,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r6_r1),
    kInstruction_teq_al_r6_r1,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r6_r2),
    kInstruction_teq_al_r6_r2,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r6_r3),
    kInstruction_teq_al_r6_r3,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r6_r4),
    kInstruction_teq_al_r6_r4,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r6_r5),
    kInstruction_teq_al_r6_r5,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r6_r6),
    kInstruction_teq_al_r6_r6,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r6_r7),
    kInstruction_teq_al_r6_r7,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r6_r8),
    kInstruction_teq_al_r6_r8,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r6_r9),
    kInstruction_teq_al_r6_r9,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r6_r10),
    kInstruction_teq_al_r6_r10,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r6_r11),
    kInstruction_teq_al_r6_r11,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r6_r12),
    kInstruction_teq_al_r6_r12,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r6_r13),
    kInstruction_teq_al_r6_r13,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r6_r14),
    kInstruction_teq_al_r6_r14,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r7_r0),
    kInstruction_teq_al_r7_r0,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r7_r1),
    kInstruction_teq_al_r7_r1,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r7_r2),
    kInstruction_teq_al_r7_r2,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r7_r3),
    kInstruction_teq_al_r7_r3,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r7_r4),
    kInstruction_teq_al_r7_r4,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r7_r5),
    kInstruction_teq_al_r7_r5,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r7_r6),
    kInstruction_teq_al_r7_r6,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r7_r7),
    kInstruction_teq_al_r7_r7,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r7_r8),
    kInstruction_teq_al_r7_r8,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r7_r9),
    kInstruction_teq_al_r7_r9,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r7_r10),
    kInstruction_teq_al_r7_r10,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r7_r11),
    kInstruction_teq_al_r7_r11,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r7_r12),
    kInstruction_teq_al_r7_r12,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r7_r13),
    kInstruction_teq_al_r7_r13,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r7_r14),
    kInstruction_teq_al_r7_r14,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r8_r0),
    kInstruction_teq_al_r8_r0,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r8_r1),
    kInstruction_teq_al_r8_r1,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r8_r2),
    kInstruction_teq_al_r8_r2,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r8_r3),
    kInstruction_teq_al_r8_r3,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r8_r4),
    kInstruction_teq_al_r8_r4,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r8_r5),
    kInstruction_teq_al_r8_r5,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r8_r6),
    kInstruction_teq_al_r8_r6,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r8_r7),
    kInstruction_teq_al_r8_r7,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r8_r8),
    kInstruction_teq_al_r8_r8,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r8_r9),
    kInstruction_teq_al_r8_r9,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r8_r10),
    kInstruction_teq_al_r8_r10,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r8_r11),
    kInstruction_teq_al_r8_r11,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r8_r12),
    kInstruction_teq_al_r8_r12,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r8_r13),
    kInstruction_teq_al_r8_r13,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r8_r14),
    kInstruction_teq_al_r8_r14,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r9_r0),
    kInstruction_teq_al_r9_r0,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r9_r1),
    kInstruction_teq_al_r9_r1,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r9_r2),
    kInstruction_teq_al_r9_r2,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r9_r3),
    kInstruction_teq_al_r9_r3,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r9_r4),
    kInstruction_teq_al_r9_r4,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r9_r5),
    kInstruction_teq_al_r9_r5,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r9_r6),
    kInstruction_teq_al_r9_r6,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r9_r7),
    kInstruction_teq_al_r9_r7,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r9_r8),
    kInstruction_teq_al_r9_r8,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r9_r9),
    kInstruction_teq_al_r9_r9,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r9_r10),
    kInstruction_teq_al_r9_r10,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r9_r11),
    kInstruction_teq_al_r9_r11,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r9_r12),
    kInstruction_teq_al_r9_r12,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r9_r13),
    kInstruction_teq_al_r9_r13,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r9_r14),
    kInstruction_teq_al_r9_r14,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r10_r0),
    kInstruction_teq_al_r10_r0,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r10_r1),
    kInstruction_teq_al_r10_r1,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r10_r2),
    kInstruction_teq_al_r10_r2,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r10_r3),
    kInstruction_teq_al_r10_r3,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r10_r4),
    kInstruction_teq_al_r10_r4,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r10_r5),
    kInstruction_teq_al_r10_r5,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r10_r6),
    kInstruction_teq_al_r10_r6,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r10_r7),
    kInstruction_teq_al_r10_r7,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r10_r8),
    kInstruction_teq_al_r10_r8,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r10_r9),
    kInstruction_teq_al_r10_r9,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r10_r10),
    kInstruction_teq_al_r10_r10,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r10_r11),
    kInstruction_teq_al_r10_r11,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r10_r12),
    kInstruction_teq_al_r10_r12,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r10_r13),
    kInstruction_teq_al_r10_r13,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r10_r14),
    kInstruction_teq_al_r10_r14,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r11_r0),
    kInstruction_teq_al_r11_r0,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r11_r1),
    kInstruction_teq_al_r11_r1,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r11_r2),
    kInstruction_teq_al_r11_r2,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r11_r3),
    kInstruction_teq_al_r11_r3,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r11_r4),
    kInstruction_teq_al_r11_r4,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r11_r5),
    kInstruction_teq_al_r11_r5,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r11_r6),
    kInstruction_teq_al_r11_r6,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r11_r7),
    kInstruction_teq_al_r11_r7,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r11_r8),
    kInstruction_teq_al_r11_r8,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r11_r9),
    kInstruction_teq_al_r11_r9,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r11_r10),
    kInstruction_teq_al_r11_r10,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r11_r11),
    kInstruction_teq_al_r11_r11,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r11_r12),
    kInstruction_teq_al_r11_r12,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r11_r13),
    kInstruction_teq_al_r11_r13,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r11_r14),
    kInstruction_teq_al_r11_r14,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r12_r0),
    kInstruction_teq_al_r12_r0,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r12_r1),
    kInstruction_teq_al_r12_r1,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r12_r2),
    kInstruction_teq_al_r12_r2,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r12_r3),
    kInstruction_teq_al_r12_r3,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r12_r4),
    kInstruction_teq_al_r12_r4,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r12_r5),
    kInstruction_teq_al_r12_r5,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r12_r6),
    kInstruction_teq_al_r12_r6,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r12_r7),
    kInstruction_teq_al_r12_r7,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r12_r8),
    kInstruction_teq_al_r12_r8,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r12_r9),
    kInstruction_teq_al_r12_r9,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r12_r10),
    kInstruction_teq_al_r12_r10,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r12_r11),
    kInstruction_teq_al_r12_r11,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r12_r12),
    kInstruction_teq_al_r12_r12,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r12_r13),
    kInstruction_teq_al_r12_r13,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r12_r14),
    kInstruction_teq_al_r12_r14,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r13_r0),
    kInstruction_teq_al_r13_r0,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r13_r1),
    kInstruction_teq_al_r13_r1,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r13_r2),
    kInstruction_teq_al_r13_r2,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r13_r3),
    kInstruction_teq_al_r13_r3,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r13_r4),
    kInstruction_teq_al_r13_r4,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r13_r5),
    kInstruction_teq_al_r13_r5,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r13_r6),
    kInstruction_teq_al_r13_r6,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r13_r7),
    kInstruction_teq_al_r13_r7,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r13_r8),
    kInstruction_teq_al_r13_r8,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r13_r9),
    kInstruction_teq_al_r13_r9,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r13_r10),
    kInstruction_teq_al_r13_r10,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r13_r11),
    kInstruction_teq_al_r13_r11,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r13_r12),
    kInstruction_teq_al_r13_r12,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r13_r13),
    kInstruction_teq_al_r13_r13,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r13_r14),
    kInstruction_teq_al_r13_r14,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r14_r0),
    kInstruction_teq_al_r14_r0,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r14_r1),
    kInstruction_teq_al_r14_r1,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r14_r2),
    kInstruction_teq_al_r14_r2,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r14_r3),
    kInstruction_teq_al_r14_r3,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r14_r4),
    kInstruction_teq_al_r14_r4,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r14_r5),
    kInstruction_teq_al_r14_r5,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r14_r6),
    kInstruction_teq_al_r14_r6,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r14_r7),
    kInstruction_teq_al_r14_r7,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r14_r8),
    kInstruction_teq_al_r14_r8,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r14_r9),
    kInstruction_teq_al_r14_r9,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r14_r10),
    kInstruction_teq_al_r14_r10,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r14_r11),
    kInstruction_teq_al_r14_r11,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r14_r12),
    kInstruction_teq_al_r14_r12,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r14_r13),
    kInstruction_teq_al_r14_r13,
  },
  {
    ARRAY_SIZE(kInstruction_teq_al_r14_r14),
    kInstruction_teq_al_r14_r14,
  },
};

#endif  // VIXL_ASSEMBLER_COND_RD_OPERAND_RN_TEQ_T32_H_
